EncryptionService class abstract

Service responsible for managing encryption keys for secure storage.

Implementers

Constructors

EncryptionService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOrCreateEncryptionKey() → Future<List<int>>
Retrieves an existing encryption key or generates a new one.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited