EncryptionServiceImpl class

Implemented types

Constructors

EncryptionServiceImpl(FlutterSecureStorage _secureStorage)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOrCreateEncryptionKey() → Future<List<int>>
Retrieves an existing encryption key or generates a new one.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited