DevToolsService class

Service to bridge the repository activities with Flutter DevTools.

Constructors

DevToolsService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

logRepositoryUpdate(String boxName, String action) → void
Logs a general repository update (e.g., cache refresh).
logSyncEvent(SyncEvent event) → void
Posts a synchronization event to the Dart developer stream.