HiveLocalDataSource<T> class

A generic implementation of LocalDataSource using Hive. T is the entity type, which must have a registered Hive adapter. Generic Hive implementation with optional AES-256 encryption support.

Implemented types

Constructors

HiveLocalDataSource(String boxName, {List<int>? encryptionKey})

Properties

boxName → String
final
encryptionKey → List<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id) → Future<void>
override
getAll() → Future<List<T>>
override
getById(String id) → Future<T?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(T item) → Future<void>
override
saveAll(List<T> items) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited