HiveOfflineQueue<T> class

Hive-backed implementation of OfflineQueue.

boxName allows multiple queues (e.g. one per repository type). Defaults to defaultBoxName if not specified.

Implemented types

Constructors

HiveOfflineQueue({String? boxName})

Properties

boxName → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
override
enqueue(OfflineAction<T> action) → Future<void>
override
getAll() → Future<List<OfflineAction<T>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String actionId) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultBoxName → const String