LocalDataSource<T> class abstract

Implementers

Constructors

LocalDataSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id) → Future<void>
getAll() → Future<List<T>>
getById(String id) → Future<T?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(T item) → Future<void>
saveAll(List<T> items) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited