RemoteDataSource<T> class abstract

Constructors

RemoteDataSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(T item) → Future<void>
delete(String id) → Future<void>
fetchAll() → Future<List<T>>
fetchById(String id) → Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(T item) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited